Changelog
=========

.. include:: includes/all.rst

This project adheres to `Semantic Versioning <http://semver.org/spec/v2.0.0.html>`__
and `human-readable changelog <http://keepachangelog.com/en/0.3.0/>`__.


yaml4rst master - unreleased
----------------------------

.. _yaml4rst master: https://github.com/ypid/yaml4rst/compare/v0.1.1...master


`yaml4rst v0.1.1`_ - 2016-11-05
-------------------------------

.. _yaml4rst v0.1.1: https://github.com/ypid/yaml4rst/compare/v0.1.0...v0.1.1

Fixed
~~~~~

- Fix legacy reST section detection when heading is directly follows by a comment. [ypid_]

- Fix YAML block detection which lead to wrong indention of closing folds. [ypid_]


yaml4rst v0.1.0 - 2016-10-28
----------------------------

Added
~~~~~

- Initial coding and design. [ypid_]
